.. _optimizers:

Optimizers
==========

.. autoclass:: mumott.optimization.optimizers.LBFGS
   :members:
   :inherited-members:

.. autoclass:: mumott.optimization.optimizers.GradientDescent
   :members:
   :inherited-members:
